@@ -6,9 +6,11 @@ use std::num::ParseIntError;
 
 use base16::DecodeError;
 use bounded_vec::BoundedVecOutOfBounds;
-use ergo_lib::ergo_chain_types::Digest32Error;
+use ergo_lib::ergo_chain_types::DigestNError;
 use ergo_lib::ergo_nipopow::NipopowProofError;
-use ergo_lib::ergo_rest::NodeError;
+#[cfg(feature = "rest")]
+use ergo_lib::ergo_rest::{NodeError, PeerDiscoveryError};
+use ergo_lib::ergotree_interpreter::sigma_protocol::verifier::VerifierError;
 use ergo_lib::ergotree_ir::chain::address::AddressEncoderError;
 use ergo_lib::ergotree_ir::chain::address::AddressError;
 use ergo_lib::ergotree_ir::chain::ergo_box::box_value::BoxValueError;
@@ -28,6 +30,8 @@ use ergo_lib::{
     wallet::{box_selector::BoxSelectorError, tx_builder::TxBuilderError, WalletError},
 };
 use serde_json::error::Error;
+#[cfg(feature = "rest")]
+use url::ParseError;
 use wasm_bindgen::JsValue;
 
 /// Ideally we'd like to implement `From<E> for JsValue` for a range of different `ergo-lib` error
@@ -56,7 +60,7 @@ from_error_to_wrap!(AddressEncoderError);
 from_error_to_wrap!(ErgoBoxCandidateBuilderError);
 from_error_to_wrap!(TryExtractFromError);
 from_error_to_wrap!(BoxSelectorError);
-from_error_to_wrap!(Digest32Error);
+from_error_to_wrap!(DigestNError);
 from_error_to_wrap!(SigmaSerializationError);
 from_error_to_wrap!(Error);
 from_error_to_wrap!(BoxValueError);
@@ -88,4 +92,10 @@ from_error_to_wrap_via_debug!(ExtSecretKeyError);
 from_error_to_wrap_via_debug!(DerivationPathError);
 from_error_to_wrap_via_debug!(ExtPubKeyError);
 from_error_to_wrap_via_debug!(NipopowProofError);
+from_error_to_wrap_via_debug!(VerifierError);
+#[cfg(feature = "rest")]
 from_error_to_wrap_via_debug!(NodeError);
+#[cfg(feature = "rest")]
+from_error_to_wrap_via_debug!(ParseError);
+#[cfg(feature = "rest")]
+from_error_to_wrap_via_debug!(PeerDiscoveryError);
